# -*- Mode: rpm-spec -*-
# 	$Id: kernel-2.4.spec,v 1.2 2001/04/05 20:07:18 chmou Exp $	

%define sublevel 21
%define mdkrelease 1mdk

# really deep magic to make things compiled depending of 
# rc & pre patches.  We want to always use the next value.
# if you dont' use it, define it as 0.
%define use_patch pre4


# When we are using a pre/rc patch, the tarboll is a sublevel -1
%if %use_patch
%define tar_version 2.4.%(expr %sublevel - 1)
%define patch_version 2.4.%{sublevel}-%use_patch
%define release 0.%{use_patch}.%mdkrelease
%else
%define tar_version 2.4.%sublevel
%define release %mdkrelease
%endif

%define version 2.4.%{sublevel}
%define KVERREL %{version}-%{release}linus

# build de docs?
%define build_doc 1

%{?_without_doc: %{expand: %%define build_doc 0}}

%{?_with_doc: %{expand: %%define build_doc 1}}

Summary: The Linux kernel (the core of the Linux operating system).
Name: kernel-linus2.4
Version: %{version}
Release: %{release}
License: GPL
Group: System/Kernel and hardware
ExclusiveArch: %{ix86} alpha ppc x86_64
ExclusiveOS: Linux
URL: http://www.kernel.org/

####################################################################
#
# Sources
#

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{tar_version}.tar.bz2
Source1: README.kernel-linus

Source21: kernel-%{version}-alpha.config
Source22: kernel-%{version}-i386.config
Source23: kernel-%{version}-ppc.config
Source24: kernel-%{version}-x86_64.config

# Patches
#
# Please don't remove this line, sometimes we want to release a linus kernel
# for a prerelease or release candidate
#
# Patches for problems in linus kernel

%if %use_patch
Patch1: patch-%patch_version.bz2
%endif

#END
####################################################################

BuildRoot: %{_tmppath}/%{name}-%{version}-build
Provides: module-info, kernel = %{version}
Autoreqprov: no
Prereq: initscripts >= 5.83-4mdk
Requires: modutils >= 2.4.3-2mdk, devfsd
BuildRequires: libbinutils2-devel, bison
BuildRequires: gcc, gcc-cpp

%if %{build_doc}
# welcome to make htmldocs psdocs pdfdocs
BuildRequires: ghostscript sgml-tools jadetex
BuildRequires: docbook-utils-pdf
# yes, we need both
BuildRequires: docbook-dtd41-sgml docbook-dtd31-sgml
BuildRequires: docbook-style-dsssl-doc
BuildRequires: tetex-dvips tetex-latex transfig 
%endif

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandrake Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.


%package -n kernel-doc-html
Version: %{version}
Release: %{release}
Summary: Various books about the kernel APIs in html format
Group: Books/Computer books

%description -n kernel-doc-html

This packages contains various books about the kernel generated from
the sources.

%package -n kernel-doc-ps
Version: %{version}
Release: %{release}
Summary: Various books about the kernel APIs in ps format
Group: Books/Computer books

%description -n kernel-doc-ps

This packages contains various books about the kernel generated from
the sources.

%package -n kernel-doc-pdf
Version: %{version}
Release: %{release}
Summary: Various books about the kernel APIs in html format
Group: Books/Computer books

%description -n kernel-doc-pdf

This packages contains various books about the kernel generated from
the sources.

#
# End packages - here begins build stage
#
%prep
%setup -q -n linux-%tar_version

%if %use_patch
%patch1 -p1
%endif

install -m 644 %SOURCE1 .

# install the config files for all the archs

install -m 644 %SOURCE21 .config
make ARCH=alpha oldconfig
install -m 644 .config arch/alpha/defconfig

install -m 644 %SOURCE22 .config
make ARCH=i386 oldconfig
install -m 644 .config arch/i386/defconfig

install -m 644 %SOURCE23 .config
make ARCH=ppc oldconfig
install -m 644 .config arch/ppc/defconfig

install -m 644 %SOURCE24 .config
make ARCH=x86_64 oldconfig
install -m 644 .config arch/x86_64/defconfig

###
### build
###

%build

# Common target directories
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _htmldir /usr/share/doc/kernel-html
%define _pdfdir /usr/share/doc/kernel-pdf
%define _psdir /usr/share/doc/kernel-ps

# Directories definition needed for building
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}
%define target_html %{buildroot}%{_htmldir}
%define target_pdf %{buildroot}%{_pdfdir}
%define target_ps %{buildroot}%{_psdir}

DependKernel() {
	flavour=$1
	echo "Make dep for kernel $flavour"
	%make -s mrproper

	# it is safest that trusting in defconfig
	cp arch/%{_arch}/defconfig .config

	ext=$flavour
	# make sure ETXRAVERSION says what we want it to say
	perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$ext/" Makefile
	%make oldconfig
	%make dep
}

BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"
	
	%ifarch alpha
	%make boot
	%endif    

	%ifarch ppc
	%make vmlinux
	%endif

	%ifarch %{ix86} x86_64
	%make bzImage
	%endif

	%make modules
}

CreateKernel() {
	flavour=$1
	KernelVer=%{KVERREL}
	DependKernel $flavour
	BuildKernel $KernelVer
}

###
# DO it...
###

# Make new ARCH config files if we don't have them.
CreateKernel linus

# don't do it before CreateKernel, or make mrproper will eat them.
# don't put here %make, as there is not propers dependencies
# do this first, as sgml tools fail/change a lot
%if %build_doc
make htmldocs psdocs pdfdocs
%endif

###
### install
###
%install

rm -rf %{buildroot}

%if %build_doc
install -d %{target_ps}
cp -a Documentation/DocBook/*\.ps %{target_ps}
install -d %{target_pdf}
cp -a Documentation/DocBook/*\.pdf %{target_pdf}
install -d %{target_html}
pushd Documentation/DocBook
find * -type d -exec cp -a {} %{target_html}/{} \;
popd
%endif

## Start installing stuff
KernelVer=%{KVERREL}
install -d %{target_boot}
install -m 644 System.map %{target_boot}/System.map-$KernelVer
install -m 644 .config %{target_boot}/config-$KernelVer

%ifarch alpha
cp -f arch/alpha/boot/vmlinux.gz %{target_boot}//vmlinuz-$KernelVer
%endif
%ifarch ppc
cp -f vmlinux %{target_boot}/vmlinuz-$KernelVer
%endif
%ifarch %{ix86}
cp -f arch/i386/boot/bzImage %{target_boot}/vmlinuz-$KernelVer
%endif
%ifarch x86_64
cp -f arch/x86_64/boot/bzImage %{target_boot}/vmlinuz-$KernelVer
%endif

# modules
install -d %{target_modules}/$KernelVer
%make INSTALL_MOD_PATH=%{buildroot} KERNELRELEASE=$KernelVer modules_install 

echo "GZIPPING Modules"
find %{target_modules} -type f -name '*.o'|xargs gzip -9f
for i in $(find %{target_modules} -type l -name '*.o');do
    link=$(perl -e 'print readlink shift, "\n"' $i)
    ln -s $link.gz $i.gz
    rm -f $i
done
# we want nice modules.dep files, and we need to regenerate them due to 
# the compression (change date)
/sbin/depmod -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$KernelVer $KernelVer

###
### clean
###

%clean
rm -rf %{buildroot}

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%preun
/sbin/modprobe loop 2> /dev/null > /dev/null
rm -f %{_modulesdir}/%{KVERREL}/modules.*

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}secure

exit 0

%post
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c %{KVERREL}
fi

%postun
cd %{_bootdir}
if [ -f initrd-%{KVERREL}.img ];then
		rm -f initrd-%{KVERREL}.img
fi

###
### file lists
###

%files
%defattr(-,root,root)
%doc README.kernel-linus
%{_bootdir}/config-%{KVERREL}
%{_bootdir}/vmlinuz-%{KVERREL}
%{_bootdir}/System.map-%{KVERREL}
%{_modulesdir}/%{KVERREL}/kernel
%{_modulesdir}/%{KVERREL}/pcmcia
%{_modulesdir}/%{KVERREL}/modules.*

%if %build_doc

%files -n kernel-doc-html
%defattr(-,root,root)
%doc %{_htmldir}

%files -n kernel-doc-pdf
%defattr(-,root,root)
%doc %{_pdfdir}

%files -n kernel-doc-ps
%defattr(-,root,root)
%doc %{_psdir}

#endif build_doc	
%endif

%changelog
* Fri Jan 31 2003 Juan Quintela <quintela@mandrakesoft.com> 2.4.21-0.pre4.1mdk
- 2.4.21-pre4.

* Mon Dec 23 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.21-1pre2mdk
- update configs.
- integrate x86_64 and make sure that it compiles.
- 2.4.21-pre2.

* Fri Nov 29 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.%{sublevel}-1mdk
- 2.4.20.

* Wed Nov 27 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.20-0.2mdk
- Fix README.linus name is README.kernel-linus
- 2.4.20-rc4.

* Thu Nov 14 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.20-0.1mdk
- enable ACPI in i586.
- create a way to compile pre & rc kernels easily.
- add x86_64 support.
- remove last sparc & sparc64 vestiges.
- 2.4.20-rc1.

* Sun Aug  4 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.19-1mdk
- remove /lib/modules/%KVERREL/build symlink, as there are no kernel source 
  package for this kernel.
- update configs.
- remove BuildRequires netpbm, libnetpbm-devel.
- 2.4.19.

* Tue Feb 26 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.18-1mdk
- create actualized modules.* info.
- make all the build system more similar to the one for mdk kernels.
- remove the InstallConfigs thing, now it is more similar to normal kernel
  (we need a best way to deal with it).
- update %pre, %post scripts to the ones in kernel-mdk.
- README.linus is its own package now.
- remove vestigies of kgcc, it is known that it misscompiles some modules.
- s/kversion/version/.
- remove unused source files.
- remove rhkmvtag.c, not used.
- remove our only patch, now this is a _real_ linus kernel.
- remove alsa.
- 2.4.18.

* Sat Jan  5 2002 Juan Quintela <quintela@mandrakesoft.com> 2.4.17-1mdk
- remove devfs creation of /dev/root.
- alsa 0.5.12a.
- 2.4.17.

* Wed Dec 19 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.16-5mdk
- 2.4.17-rc1.

* Fri Dec 14 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.16-4mdk
- fix the modules building problem.
- add PCMCIA support.

* Tue Dec 11 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 2.4.16-3mdk
- add i686 config

* Wed Dec  5 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 2.4.16-2mdk
- update alpha config to fix build

* Mon Nov 26 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.16-1mdk
- 2.4.16.

* Mon Nov 26 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.15-4mdk
- add patch for fixing compilation in ppc (P101).

* Sat Nov 24 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.15-3mdk
- added patch100 to fix inode corruption.
- remove saved headers black magic.
- move removal of the kernel from %postun to %preun.
- remove 3rdparty vestiges.
- inline defines that was used only one (prereq, requires, provides).
- use gcc-2.96 by default.
- remove boot_logo (was unused).
- remove %build_boot.
- remove %build_up.
- remove %build_smp.
- remove %build_enterprise.
- remove %build_pcmcia.
- remove %build_80.

* Fri Nov 23 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.15-2mdk
- remove P1 (applied upstream).
- add Provides to make rpmlint happy.
- remove last use of $RPM_SOURCE_DIR.
- add URL tag.

* Fri Nov 23 2001 Juan Quintela <quintela@mandrakesoft.com> 2.4.15-1mdk
- fix places that used %{KVERREL} instead of %{KVERREL}linus.
- update all the configs.
- alsa-0.5.12.
- 2.4.15.

* Sat Oct 27 2001 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.13-2mdk
- modify config for PPC build (disable SUNGEM)

* Fri Oct 26 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 2.4.13-1mdk
- Version 2.4.13.
- Update arch configs.

* Fri Oct 19 2001 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.12-1mdk
- 2.4.12, update ARCH config files for build - UpdateConfigs
- remove $RPM_SOURCE_DIR, s/Linux Mandrake/Mandrake Linux/

* Thu Oct  4 2001 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.4.10-1mdk
- 2.4.10.
- Fix postscripts

* Thu Aug 16 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.8-1mdk
- remove logo (no patch at all)
- new release
- sync with main kernel spec
- add alsa (after all, it doesn't alter any kernel source bit)

* Tue Aug 07 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.7-1mdk
- enable to build more than a kernel at a time
- new release

* Mon Jul 16 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.6-3mdk
- add a README.linus

* Sun Jul 15 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 2.4.6-2mdk
- update alpha config

* Wed Jul  4 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 2.4.6-1mdk
- new release
- remove use of RPM_SOURCE_DIR (fix rpmlint errors)

* Thu Jun 21 2001 Stefan van der Eijk <stefan@eijk.nu> 2.4.5-2mdk
- BuildRequires: libgr-devel

* Tue Jun 19 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.5-1mdk
- new release

* Thu May 03 2001 Stefan van der Eijk <s.vandereijk@chello.nl> 2.4.4-2mdk
- update alpha .config

* Wed May 02 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.4-1mdk
- new version
- last %%post fix (which simplify the spec by the way)

* Fri Apr 13 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.3-2mdk
- remove documentation (already in kernel-doc)
- readd dead %%post
- update logo

* Mon Apr 02 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.3-1mdk
- new release
- fix buz.c compilation
- reduce the number of places where to alter release number

* Tue Mar 15 2001 Stefan van der Eijk <s.vandereijk@chello.nl> 2.4.2-2mdk
- update alpha + i586 .config

* Wed Feb 28 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.2-1mdk
- fix 6pack driver
- new stable version

* Wed Jan 31 2001 Stefan van der Eijk <s.vandereijk@chello.nl> 2.4.1-2mdk
- add alpha .config file

* Tue Jan 30 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.1-1mdk
- first release as requested by Chmouel

# Local Variables:
# rpm-spec-insert-changelog-version-with-shell: t
# End:
